-
-
-
diff --git a/.idea/vcs.xml b/.idea/vcs.xml
deleted file mode 100644
index 94a25f7..0000000
--- a/.idea/vcs.xml
+++ /dev/null
@@ -1,6 +0,0 @@
-
-
-
-
-
-
\ No newline at end of file
diff --git a/README.md b/README.md
index d6fc1fd..aa14469 100644
--- a/README.md
+++ b/README.md
@@ -1,2 +1,2 @@
-# ForgeModTemplate
+# ${REPO_NAME}
diff --git a/build.gradle b/build.gradle
index 6c4c07f..b6cc936 100644
--- a/build.gradle
+++ b/build.gradle
@@ -5,8 +5,8 @@ plugins {
}
version = '1.0'
-group = 'moe.nekojimi.testmod' // http://maven.apache.org/guides/mini/guide-naming-conventions.html
-archivesBaseName = 'TestMod'
+group = 'moe.nekojimi.${REPO_NAME_LOWER}' // http://maven.apache.org/guides/mini/guide-naming-conventions.html
+archivesBaseName = '${REPO_NAME_PASCAL}'
// Mojang ships Java 17 to end users in 1.18+, so your mod should target Java 17.
java.toolchain.languageVersion = JavaLanguageVersion.of(17)
@@ -49,7 +49,7 @@ minecraft {
property 'forge.logging.console.level', 'debug'
// Comma-separated list of namespaces to load gametests from. Empty = all namespaces.
- property 'forge.enabledGameTestNamespaces', 'TestMod'
+ property 'forge.enabledGameTestNamespaces', '${REPO_NAME_PASCAL}'
mods {
examplemod {
@@ -65,10 +65,10 @@ minecraft {
property 'forge.logging.console.level', 'debug'
- property 'forge.enabledGameTestNamespaces', 'TestMod'
+ property 'forge.enabledGameTestNamespaces', '${REPO_NAME_PASCAL}'
mods {
- examplemod {
+ ${REPO_NAME_LOWER} {
source sourceSets.main
}
}
@@ -84,7 +84,7 @@ minecraft {
property 'forge.logging.console.level', 'debug'
- property 'forge.enabledGameTestNamespaces', 'TestMod'
+ property 'forge.enabledGameTestNamespaces', '${REPO_NAME_PASCAL}'
mods {
examplemod {
@@ -148,7 +148,7 @@ dependencies {
jar {
manifest {
attributes([
- "Specification-Title" : "TestMod",
+ "Specification-Title" : "${REPO_NAME_PASCAL}",
"Specification-Vendor" : "examplemodsareus",
"Specification-Version" : "1", // We are version 1 of ourselves
"Implementation-Title" : project.name,
diff --git a/src/main/java/com/example/examplemod/ExampleMod.java b/src/main/java/com/example/examplemod/ExampleMod.java
index 48b8fd6..1aa8f11 100644
--- a/src/main/java/com/example/examplemod/ExampleMod.java
+++ b/src/main/java/com/example/examplemod/ExampleMod.java
@@ -1,4 +1,4 @@
-package com.example.examplemod;
+package com.example.${REPO_NAME_LOWER};
import com.mojang.logging.LogUtils;
import net.minecraft.client.Minecraft;
@@ -26,24 +26,24 @@ import net.minecraftforge.registries.RegistryObject;
import org.slf4j.Logger;
// The value here should match an entry in the META-INF/mods.toml file
-@Mod(ExampleMod.MODID)
-public class ExampleMod
+@Mod(${REPO_NAME_PASCAL}.MODID)
+public class ${REPO_NAME_PASCAL}
{
// Define mod id in a common place for everything to reference
- public static final String MODID = "examplemod";
+ public static final String MODID = "${REPO_NAME_LOWER}";
// Directly reference a slf4j logger
private static final Logger LOGGER = LogUtils.getLogger();
// Create a Deferred Register to hold Blocks which will all be registered under the "examplemod" namespace
public static final DeferredRegister BLOCKS = DeferredRegister.create(ForgeRegistries.BLOCKS, MODID);
// Create a Deferred Register to hold Items which will all be registered under the "examplemod" namespace
public static final DeferredRegister ITEMS = DeferredRegister.create(ForgeRegistries.ITEMS, MODID);
// Creates a new Block with the id "examplemod:example_block", combining the namespace and path
public static final RegistryObject EXAMPLE_BLOCK = BLOCKS.register("example_block", () -> new Block(BlockBehaviour.Properties.of(Material.STONE)));
// Creates a new BlockItem with the id "examplemod:example_block", combining the namespace and path
public static final RegistryObject EXAMPLE_BLOCK_ITEM = ITEMS.register("example_block", () -> new BlockItem(EXAMPLE_BLOCK.get(), new Item.Properties().tab(CreativeModeTab.TAB_BUILDING_BLOCKS)));
- public ExampleMod()
+ public ${REPO_NAME_PASCAL}()
{
IEventBus modEventBus = FMLJavaModLoadingContext.get().getModEventBus();
@@ -26,24 +26,24 @@ import net.minecraftforge.registries.RegistryObject;
// Directly reference a slf4j logger
private static final Logger LOGGER = LogUtils.getLogger();
- // Create a Deferred Register to hold Blocks which will all be registered under the "examplemod" namespace
+ // Create a Deferred Register to hold Blocks which will all be registered under the "${REPO_NAME_LOWER}" namespace
public static final DeferredRegister BLOCKS = DeferredRegister.create(ForgeRegistries.BLOCKS, MODID);
@@ -26,24 +26,24 @@ import net.minecraftforge.registries.RegistryObject;
public static final DeferredRegister BLOCKS = DeferredRegister.create(ForgeRegistries.BLOCKS, MODID);
- // Create a Deferred Register to hold Items which will all be registered under the "examplemod" namespace
+ // Create a Deferred Register to hold Items which will all be registered under the "${REPO_NAME_LOWER}" namespace
public static final DeferredRegister ITEMS = DeferredRegister.create(ForgeRegistries.ITEMS, MODID);
@@ -26,24 +26,24 @@ import net.minecraftforge.registries.RegistryObject;
public static final DeferredRegister ITEMS = DeferredRegister.create(ForgeRegistries.ITEMS, MODID);
- // Creates a new Block with the id "examplemod:example_block", combining the namespace and path
+ // Creates a new Block with the id "${REPO_NAME_LOWER}:example_block", combining the namespace and path
public static final RegistryObject EXAMPLE_BLOCK = BLOCKS.register("example_block", () -> new Block(BlockBehaviour.Properties.of(Material.STONE)));
@@ -26,24 +26,24 @@ import net.minecraftforge.registries.RegistryObject;
public static final RegistryObject EXAMPLE_BLOCK = BLOCKS.register("example_block", () -> new Block(BlockBehaviour.Properties.of(Material.STONE)));
- // Creates a new BlockItem with the id "examplemod:example_block", combining the namespace and path
+ // Creates a new BlockItem with the id "${REPO_NAME_LOWER}:example_block", combining the namespace and path
public static final RegistryObject EXAMPLE_BLOCK_ITEM = ITEMS.register("example_block", () -> new BlockItem(EXAMPLE_BLOCK.get(), new Item.Properties().tab(CreativeModeTab.TAB_BUILDING_BLOCKS)));